@@ -7,8 +7,9 @@
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
 #'@param includeIntercept Boolean whether the y-intercept should be included
-#'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables 
-#'@param ... Additional arguments to be passed to the 'lm' function
+#'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables
+#'@param weights Optional vector of weights to be passed to the fitting process
+#'@param ... Additional arguments to be passed to the 'lm' function (careful in that these may need to be modified for ecm or may not be appropriate!)
 #'@return an lm object representing an error correction model using backwards selection
 #'@details
 #'When inputting a single variable for xeq or xtr, it is important to input it in the format "xeq=df['col1']" in order to retain the data frame class. Inputting such as "xeq=df[,'col1']" or "xeq=df$col1" will result in errors in the ecm function.
@@ -18,8 +19,8 @@
 #'#Federal Reserve funds rate, and unemployment rate
 #'data(Wilshire)
 #'
-#'#Use 2014-12-01 and earlier data to build models
-#'trn <- Wilshire[Wilshire$date<='2014-12-01',]
+#'#Use 2015-12-01 and earlier data to build models
+#'trn <- Wilshire[Wilshire$date<='2015-12-01',]
 #'
 #'#Use backwards selection to choose which predictors are needed 
 #'xeq <- xtr <- trn[c('CorpProfits', 'FedFundsRate', 'UnempRate')]
@@ -30,7 +31,7 @@
 #'
 #'@export
 #'@importFrom stats lm complete.cases step
-ecmback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", ...) {
+ecmback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", weights = NULL, ...) {
   if (sum(grepl("^delta|Lag1$", names(xtr))) > 0 | sum(grepl("^delta|Lag1$", names(xeq))) > 0) {
     warning("You have column name(s) in xeq or xtr that begin with 'delta' or end with 'Lag1'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' will result in errors or incorrect predictions.")
   }
@@ -44,30 +45,37 @@ ecmback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", ...)
   xtrnames <- paste0("delta", xtrnames)
   xtr <- as.data.frame(xtr)
   xtr <- data.frame(apply(xtr, 2, diff, 1))
-  dy <- diff(y, 1)
   
   yLag1 <- y[1:(length(y) - 1)]
   x <- cbind(xtr, xeq[complete.cases(xeq), ])
   x <- cbind(x, yLag1)
   names(x) <- c(xtrnames, xeqnames, "yLag1")
+  x$dy <- diff(y, 1)
+  
   if (includeIntercept){
     full <- lm(dy ~ ., data = x, ...)
+    null <- lm(dy ~ yLag1, data = x)
   } else {
     full <- lm(dy ~ .-1, data = x, ...)
+    null <- lm(dy ~ yLag1 - 1, data = x)
   }
-  null <- lm(dy ~ yLag1, data = x)
+    
   if (criterion == "AIC" | criterion == "BIC") {
     if (criterion == "AIC") {
-      k = 2
+      kIC = 2
     } else if (criterion == "BIC") {
-      k = log(nrow(x))
+      kIC = log(nrow(x))
     }
-    ecm <- step(full, data = x, scope = list(upper = full, lower = null), direction = "backward", k = k, trace = 0)
+    ecm <- step(full, data = x, scope = list(upper = full, lower = null), direction = "backward", k = kIC, trace = 0)
   } else if (criterion == "adjustedR2") {
     fullAdjR2 <- partialAdjR2 <- summary(full)$adj.r.sq
     while (partialAdjR2 >= fullAdjR2) {
       fullAdjR2 <- summary(full)$adj.r.sq
-      todrop <- which.max(summary(full)$coef[-1, 4])
+      if (includeIntercept){
+        todrop <- which.max(summary(full)$coef[-1, 4])
+      } else {
+        todrop <- which.max(summary(full)$coef[, 4])
+      }
       newx <- x[which(!names(x) %in% names(todrop))]
       partial <- lm(dy ~ ., data = newx)
       partialAdjR2 <- summary(partial)$adj.r.sq
@@ -77,17 +85,18 @@ ecmback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", ...)
         if (includeIntercept){
           full <- lm(dy ~ ., data = x, ...)
         } else {
-          full <- lm(dy ~ .-1, data = x, ...)
+          full <- lm(dy ~ . - 1, data = x, ...)
         }
       } else {
         if (includeIntercept){
           ecm <- lm(dy ~ ., data = x, ...)
         } else {
-          ecm <- lm(dy ~ .-1, data = x, ...)
+          ecm <- lm(dy ~ . - 1, data = x, ...)
         }
       }
     }
-  } 
+  }
+  
   if (sum(grepl("^delta", names(ecm$coefficients))) == 0) {
     warning("Backwards selection has opted to leave out all transient terms from the final model. This means you have a first order differenced autoregressive model of sorts, not a full error correction model.")
   } else if (sum(grepl("Lag1$", names(ecm$coefficients))) == 0) {
